| Title: | Testing the Equality of Two Means Using RSS and MRSS |
|---|---|
| Description: | Testing the equality of two means using Ranked Set Sampling and Median Ranked Set Sampling are provided under normal distribution. Data generation functions are also given RSS and MRSS. Also, data generation functions are given under imperfect ranking data for Ranked Set Sampling and Median Ranked Set Sampling. Ozdemir Y.A., Ebegil M., & Gokpinar F. (2019), <doi:10.1007/s40995-018-0558-0> Ozdemir Y.A., Ebegil M., & Gokpinar F. (2017), <doi:10.1080/03610918.2016.1263736>. |
| Authors: | Fikri Gökpınar [aut, cre]
|
| Maintainer: | Fikri Gökpınar <[email protected]> |
| License: | GPL-2 |
| Version: | 1.0 |
| Built: | 2026-05-26 08:09:19 UTC |
| Source: | https://github.com/cran/RSStest |
CVT Data
data(CVT)data(CVT)
A dataframe with 167 rows 6 variables
otolith length
otolith width
otolith weight
fish lenght
fish weight
age
sex
data("CVT")data("CVT")
This function generates random samples from normal population using Median ranked set sampling with
mean and standard deviation using cycle size r and set size m.
datagen_MRSS(mu, s, m, r)datagen_MRSS(mu, s, m, r)
mu |
: Normal population mean |
s |
: Normal population standard deviation |
m |
: Set size |
r |
: Cycle size |
A sample matrix with size rxm generated from normal distribution using Median ranked set sampling. Each row indicates a cycle.
MacEachern, S. N., Öztürk, Ö., Wolfe, A. D. (2002). A new ranked set sample estimator of variance. Journal of the Royal Statistical Society: Series B., 64, Part 2 177–188.
Özturk, Ö., Balakrishnan N (2009) Exact two-sample nonparametric test for quantile difference between two populations based on ranked set samples. Ann Inst Stat Math 61(1):235–249
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2017). A test statistic based on ranked set sampling for two normal means. Communications in Statistics-Simulation and Computation, 46(10), 8077-8085.
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2019). A test statistic for two normal means with median ranked set sampling. Iranian Journal of Science and Technology, Transactions A: Science, 43(3), 1109-1126.
datagen_RSS, teststat_RSS
teststat_MRSS
datagen_MRSS(0,1,2,3)datagen_MRSS(0,1,2,3)
This function generates random samples from normal population using ranked set sampling with
mean and standard deviation using cycle size r and set size m.
datagen_RSS(mu, s, m, r)datagen_RSS(mu, s, m, r)
mu |
: Normal population mean |
s |
: Normal population standard deviation |
m |
: Set size |
r |
: Cycle size |
A sample matrix with size rxm generated from normal distribution using ranked set sampling. Each row indicates a cycle.
MacEachern, S. N., Öztürk, Ö., Wolfe, A. D. (2002). A new ranked set sample estimator of variance. Journal of the Royal Statistical Society: Series B., 64, Part 2 177–188.
Özturk, Ö., Balakrishnan N (2009) Exact two-sample nonparametric test for quantile difference between two populations based on ranked set samples. Ann Inst Stat Math 61(1):235–249
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2017). A test statistic based on ranked set sampling for two normal means. Communications in Statistics-Simulation and Computation, 46(10), 8077-8085.
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2019). A test statistic for two normal means with median ranked set sampling. Iranian Journal of Science and Technology, Transactions A: Science, 43(3), 1109-1126.
datagen_MRSS, teststat_RSS
teststat_MRSS
datagen_RSS(0,1,2,3)datagen_RSS(0,1,2,3)
This function chooses Median Ranked Set samples from specific finite population using auxiliary variable with cycle sizes r1 and r2 and set sizes m1 and m2.
imperfectMRSS(df, cat, catname, aux, var, r1, r2, m1, m2)imperfectMRSS(df, cat, catname, aux, var, r1, r2, m1, m2)
df |
: dataframe of the finite population |
cat |
: the indicator variable that shows the group of units |
catname |
: the group names |
aux |
: auxilary variable |
var |
: variable of interest |
r1 |
: Cycle size of first group |
r2 |
: Cycle size of second group |
m1 |
: Set size of first group |
m2 |
: Set size of second group |
two median ranked set sample matrix with sizes r1xm1 and r2xm2 from finite population. Each row indicates a cycle.
MacEachern, S. N., Öztürk, Ö., Wolfe, A. D. (2002). A new ranked set sample estimator of variance. Journal of the Royal Statistical Society: Series B., 64, Part 2 177–188.
Özturk, Ö., Balakrishnan N (2009) Exact two-sample nonparametric test for quantile difference between two populations based on ranked set samples. Ann Inst Stat Math 61(1):235–249
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2017). A test statistic based on ranked set sampling for two normal means. Communications in Statistics-Simulation and Computation, 46(10), 8077-8085.
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2019). A test statistic for two normal means with median ranked set sampling. Iranian Journal of Science and Technology, Transactions A: Science, 43(3), 1109-1126.
datagen_RSS, teststat_RSS
teststat_MRSS,imperfectRSS
data(otolith) imperfectMRSS(otolith,"sex",c("F","M"),"fish.length","age",3,3,4,3)data(otolith) imperfectMRSS(otolith,"sex",c("F","M"),"fish.length","age",3,3,4,3)
This function chooses Ranked Set samples from specific finite population using auxiliary variable with cycle sizes r1 and r2 and set sizes m1 and m2.
imperfectRSS(df, cat, catname, aux, var, r1, r2, m1, m2)imperfectRSS(df, cat, catname, aux, var, r1, r2, m1, m2)
df |
: dataframe of the finite population |
cat |
: the indicator variable that shows the group of units |
catname |
: the group names |
aux |
: auxilary variable |
var |
: variable of interest |
r1 |
: Cycle size of first group |
r2 |
: Cycle size of second group |
m1 |
: Set size of first group |
m2 |
: Set size of second group |
two ranked set sample matrix with sizes r1xm1 and r2xm2 from finite population. Each row indicates a cycle.
MacEachern, S. N., Öztürk, Ö., Wolfe, A. D. (2002). A new ranked set sample estimator of variance. Journal of the Royal Statistical Society: Series B., 64, Part 2 177–188.
Özturk, Ö., Balakrishnan N (2009) Exact two-sample nonparametric test for quantile difference between two populations based on ranked set samples. Ann Inst Stat Math 61(1):235–249
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2017). A test statistic based on ranked set sampling for two normal means. Communications in Statistics-Simulation and Computation, 46(10), 8077-8085.
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2019). A test statistic for two normal means with median ranked set sampling. Iranian Journal of Science and Technology, Transactions A: Science, 43(3), 1109-1126.
datagen_RSS, teststat_RSS
teststat_MRSS, imperfectMRSS
data(otolith) imperfectRSS(otolith,"sex",c("F","M"),"fish.length","age",3,3,4,3)data(otolith) imperfectRSS(otolith,"sex",c("F","M"),"fish.length","age",3,3,4,3)
The data related to otolith bone of fishes was collected from Elazığ Keban Dam Lake (November 2011-December 2012), which was a part of the data by given Doğan and Şen(2017). The data containing otolith length, otolith width, otolith weight, fish length, fish width, age and sex.
data(otolith)data(otolith)
A dataframe with 167 rows 6 variables
otolith length
otolith width
otolith weight
fish lenght
fish weight
age
sex
Doğan Y. Şen D., Otolith Biometry-Fish Lenth Relationship in Capoeta trutta Inhabiting Keban Dam Lake
data("otolith")data("otolith")
This function tests for the difference of two population means using ranked set sampling given in Özdemir, Ebegil and Gökpınar (2019).
teststat_MRSS( x1, x2, alpha = 0.05, alternative = "two-tailed", tn = 2000, table = TRUE )teststat_MRSS( x1, x2, alpha = 0.05, alternative = "two-tailed", tn = 2000, table = TRUE )
x1 |
A (non-empty) numeric matrix (m1xr1) of median ranked set sample for Group 1 with set size m1 and cycle size r1. |
x2 |
A (non-empty) numeric matrix (m2xr2) of median ranked set sample for Group 2 with set size m2 and cycle size r2. |
alpha |
A scalar value of the significance level for hypothesis testing used in the table. Default is 0.05. |
alternative |
A character string specifying the alternative hypothesis, must be one of "two-sided", "right" or "left". Can be abbreviated. Default is "two-sided". |
tn |
A scalar value of the number of repetitions of Monte Carlo simulation. Default is 2000. |
table |
A logical value that shows table gives the results of the hypothesis test are printed out. Default is TRUE. |
If table is TRUE the hypothesis test results table includes sample sizes, test statistics, p values and test results are printed out.
MacEachern, S. N., Öztürk, Ö., Wolfe, A. D. (2002). A new ranked set sample estimator of variance. Journal of the Royal Statistical Society: Series B., 64, Part 2 177–188.
Özturk, Ö., Balakrishnan N (2009) Exact two-sample nonparametric test for quantile difference between two populations based on ranked set samples. Ann Inst Stat Math 61(1):235–249
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2017). A test statistic based on ranked set sampling for two normal means. Communications in Statistics-Simulation and Computation, 46(10), 8077-8085.
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2019). A test statistic for two normal means with median ranked set sampling. Iranian Journal of Science and Technology, Transactions A: Science, 43(3), 1109-1126.
datagen_MRSS, datagen_RSS,
teststat_RSS
x1=matrix(c(1,2.3, 3.4,4.5,5.6,4 ),nrow=3) x2=matrix(c(2,3.2, 4.2,6.5,4.6,6 ),nrow=3) teststat_MRSS(x1,x2,tn=1000)x1=matrix(c(1,2.3, 3.4,4.5,5.6,4 ),nrow=3) x2=matrix(c(2,3.2, 4.2,6.5,4.6,6 ),nrow=3) teststat_MRSS(x1,x2,tn=1000)
This function tests for the difference of two population means using ranked set sampling given in Özdemir, Ebegil and Gökpınar (2017).
teststat_RSS(x1, x2, alpha = 0.05, alternative = "two-tailed", table = TRUE)teststat_RSS(x1, x2, alpha = 0.05, alternative = "two-tailed", table = TRUE)
x1 |
A (non-empty) numeric matrix (m1xr1) of ranked set sample for Group 1 with set size m1 and cycle size r1. |
x2 |
A (non-empty) numeric matrix (m2xr2) of ranked set sample for Group 2 with set size m2 and cycle size r2. |
alpha |
A scalar value of the significance level for hypothesis testing used in the table. Default is 0.05. |
alternative |
A character string specifying the alternative hypothesis, must be one of "two-sided", "right" or "left". Can be abbreviated. Default is "two-sided". |
table |
A logical value that shows table gives the results of the hypothesis test are printed out. Default is TRUE. |
If table is TRUE the hypothesis test results table includes sample sizes, test statistics, critical values and test results are printed out.
MacEachern, S. N., Öztürk, Ö., Wolfe, A. D. (2002). A new ranked set sample estimator of variance. Journal of the Royal Statistical Society: Series B., 64, Part 2 177–188.
Özturk, Ö., Balakrishnan N (2009) Exact two-sample nonparametric test for quantile difference between two populations based on ranked set samples. Ann Inst Stat Math 61(1):235–249
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2017). A test statistic based on ranked set sampling for two normal means. Communications in Statistics-Simulation and Computation, 46(10), 8077-8085.
Özdemir, Y. A., Ebegil, M., & Gökpinar, F. (2019). A test statistic for two normal means with median ranked set sampling. Iranian Journal of Science and Technology, Transactions A: Science, 43(3), 1109-1126.
@seealso datagen_MRSS, datagen_RSS, teststat_MRSS
x1=matrix(c(1,2.3, 3.4,4.5,5.6,4 ),nrow=3) x2=matrix(c(2,3.2, 4.2,6.5,4.6,6 ),nrow=3) teststat_RSS(x1,x2)x1=matrix(c(1,2.3, 3.4,4.5,5.6,4 ),nrow=3) x2=matrix(c(2,3.2, 4.2,6.5,4.6,6 ),nrow=3) teststat_RSS(x1,x2)